# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StatusUpdateResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'title': 'str',
        'resource_subtype': 'str',
        'text': 'str',
        'html_text': 'str',
        'status_type': 'str',
        'author': 'CustomFieldResponsePeopleValue',
        'created_at': 'datetime',
        'created_by': 'CustomFieldResponsePeopleValue',
        'hearted': 'bool',
        'hearts': 'list[GoalResponseLikes]',
        'liked': 'bool',
        'likes': 'list[GoalResponseLikes]',
        'modified_at': 'datetime',
        'num_hearts': 'int',
        'num_likes': 'int',
        'parent': 'StatusUpdateResponseParent'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'title': 'title',
        'resource_subtype': 'resource_subtype',
        'text': 'text',
        'html_text': 'html_text',
        'status_type': 'status_type',
        'author': 'author',
        'created_at': 'created_at',
        'created_by': 'created_by',
        'hearted': 'hearted',
        'hearts': 'hearts',
        'liked': 'liked',
        'likes': 'likes',
        'modified_at': 'modified_at',
        'num_hearts': 'num_hearts',
        'num_likes': 'num_likes',
        'parent': 'parent'
    }

    def __init__(self, gid=None, resource_type=None, title=None, resource_subtype=None, text=None, html_text=None, status_type=None, author=None, created_at=None, created_by=None, hearted=None, hearts=None, liked=None, likes=None, modified_at=None, num_hearts=None, num_likes=None, parent=None):  # noqa: E501
        """StatusUpdateResponse - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._title = None
        self._resource_subtype = None
        self._text = None
        self._html_text = None
        self._status_type = None
        self._author = None
        self._created_at = None
        self._created_by = None
        self._hearted = None
        self._hearts = None
        self._liked = None
        self._likes = None
        self._modified_at = None
        self._num_hearts = None
        self._num_likes = None
        self._parent = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if title is not None:
            self.title = title
        if resource_subtype is not None:
            self.resource_subtype = resource_subtype
        self.text = text
        if html_text is not None:
            self.html_text = html_text
        self.status_type = status_type
        if author is not None:
            self.author = author
        if created_at is not None:
            self.created_at = created_at
        if created_by is not None:
            self.created_by = created_by
        if hearted is not None:
            self.hearted = hearted
        if hearts is not None:
            self.hearts = hearts
        if liked is not None:
            self.liked = liked
        if likes is not None:
            self.likes = likes
        if modified_at is not None:
            self.modified_at = modified_at
        if num_hearts is not None:
            self.num_hearts = num_hearts
        if num_likes is not None:
            self.num_likes = num_likes
        if parent is not None:
            self.parent = parent

    @property
    def gid(self):
        """Gets the gid of this StatusUpdateResponse.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this StatusUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this StatusUpdateResponse.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this StatusUpdateResponse.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this StatusUpdateResponse.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this StatusUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this StatusUpdateResponse.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this StatusUpdateResponse.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def title(self):
        """Gets the title of this StatusUpdateResponse.  # noqa: E501

        The title of the status update.  # noqa: E501

        :return: The title of this StatusUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this StatusUpdateResponse.

        The title of the status update.  # noqa: E501

        :param title: The title of this StatusUpdateResponse.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def resource_subtype(self):
        """Gets the resource_subtype of this StatusUpdateResponse.  # noqa: E501

        The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning. The `resource_subtype`s for `status` objects represent the type of their parent.  # noqa: E501

        :return: The resource_subtype of this StatusUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._resource_subtype

    @resource_subtype.setter
    def resource_subtype(self, resource_subtype):
        """Sets the resource_subtype of this StatusUpdateResponse.

        The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning. The `resource_subtype`s for `status` objects represent the type of their parent.  # noqa: E501

        :param resource_subtype: The resource_subtype of this StatusUpdateResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["project_status_update", "portfolio_status_update", "goal_status_update"]  # noqa: E501
        if resource_subtype not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_subtype` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_subtype, allowed_values)
            )

        self._resource_subtype = resource_subtype

    @property
    def text(self):
        """Gets the text of this StatusUpdateResponse.  # noqa: E501

        The text content of the status update.  # noqa: E501

        :return: The text of this StatusUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this StatusUpdateResponse.

        The text content of the status update.  # noqa: E501

        :param text: The text of this StatusUpdateResponse.  # noqa: E501
        :type: str
        """
        if text is None:
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def html_text(self):
        """Gets the html_text of this StatusUpdateResponse.  # noqa: E501

        [Opt In](/docs/inputoutput-options). The text content of the status update with formatting as HTML.  # noqa: E501

        :return: The html_text of this StatusUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._html_text

    @html_text.setter
    def html_text(self, html_text):
        """Sets the html_text of this StatusUpdateResponse.

        [Opt In](/docs/inputoutput-options). The text content of the status update with formatting as HTML.  # noqa: E501

        :param html_text: The html_text of this StatusUpdateResponse.  # noqa: E501
        :type: str
        """

        self._html_text = html_text

    @property
    def status_type(self):
        """Gets the status_type of this StatusUpdateResponse.  # noqa: E501

        The type associated with the status update. This represents the current state of the object this object is on.  # noqa: E501

        :return: The status_type of this StatusUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._status_type

    @status_type.setter
    def status_type(self, status_type):
        """Sets the status_type of this StatusUpdateResponse.

        The type associated with the status update. This represents the current state of the object this object is on.  # noqa: E501

        :param status_type: The status_type of this StatusUpdateResponse.  # noqa: E501
        :type: str
        """
        if status_type is None:
            raise ValueError("Invalid value for `status_type`, must not be `None`")  # noqa: E501
        allowed_values = ["on_track", "at_risk", "off_track", "on_hold", "complete", "achieved", "partial", "missed", "dropped"]  # noqa: E501
        if status_type not in allowed_values:
            raise ValueError(
                "Invalid value for `status_type` ({0}), must be one of {1}"  # noqa: E501
                .format(status_type, allowed_values)
            )

        self._status_type = status_type

    @property
    def author(self):
        """Gets the author of this StatusUpdateResponse.  # noqa: E501


        :return: The author of this StatusUpdateResponse.  # noqa: E501
        :rtype: CustomFieldResponsePeopleValue
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this StatusUpdateResponse.


        :param author: The author of this StatusUpdateResponse.  # noqa: E501
        :type: CustomFieldResponsePeopleValue
        """

        self._author = author

    @property
    def created_at(self):
        """Gets the created_at of this StatusUpdateResponse.  # noqa: E501

        The time at which this resource was created.  # noqa: E501

        :return: The created_at of this StatusUpdateResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this StatusUpdateResponse.

        The time at which this resource was created.  # noqa: E501

        :param created_at: The created_at of this StatusUpdateResponse.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def created_by(self):
        """Gets the created_by of this StatusUpdateResponse.  # noqa: E501


        :return: The created_by of this StatusUpdateResponse.  # noqa: E501
        :rtype: CustomFieldResponsePeopleValue
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this StatusUpdateResponse.


        :param created_by: The created_by of this StatusUpdateResponse.  # noqa: E501
        :type: CustomFieldResponsePeopleValue
        """

        self._created_by = created_by

    @property
    def hearted(self):
        """Gets the hearted of this StatusUpdateResponse.  # noqa: E501

        *Deprecated - please use liked instead* True if the status is hearted by the authorized user, false if not.  # noqa: E501

        :return: The hearted of this StatusUpdateResponse.  # noqa: E501
        :rtype: bool
        """
        return self._hearted

    @hearted.setter
    def hearted(self, hearted):
        """Sets the hearted of this StatusUpdateResponse.

        *Deprecated - please use liked instead* True if the status is hearted by the authorized user, false if not.  # noqa: E501

        :param hearted: The hearted of this StatusUpdateResponse.  # noqa: E501
        :type: bool
        """

        self._hearted = hearted

    @property
    def hearts(self):
        """Gets the hearts of this StatusUpdateResponse.  # noqa: E501

        *Deprecated - please use likes instead* Array of likes for users who have hearted this status.  # noqa: E501

        :return: The hearts of this StatusUpdateResponse.  # noqa: E501
        :rtype: list[GoalResponseLikes]
        """
        return self._hearts

    @hearts.setter
    def hearts(self, hearts):
        """Sets the hearts of this StatusUpdateResponse.

        *Deprecated - please use likes instead* Array of likes for users who have hearted this status.  # noqa: E501

        :param hearts: The hearts of this StatusUpdateResponse.  # noqa: E501
        :type: list[GoalResponseLikes]
        """

        self._hearts = hearts

    @property
    def liked(self):
        """Gets the liked of this StatusUpdateResponse.  # noqa: E501

        True if the status is liked by the authorized user, false if not.  # noqa: E501

        :return: The liked of this StatusUpdateResponse.  # noqa: E501
        :rtype: bool
        """
        return self._liked

    @liked.setter
    def liked(self, liked):
        """Sets the liked of this StatusUpdateResponse.

        True if the status is liked by the authorized user, false if not.  # noqa: E501

        :param liked: The liked of this StatusUpdateResponse.  # noqa: E501
        :type: bool
        """

        self._liked = liked

    @property
    def likes(self):
        """Gets the likes of this StatusUpdateResponse.  # noqa: E501

        Array of likes for users who have liked this status.  # noqa: E501

        :return: The likes of this StatusUpdateResponse.  # noqa: E501
        :rtype: list[GoalResponseLikes]
        """
        return self._likes

    @likes.setter
    def likes(self, likes):
        """Sets the likes of this StatusUpdateResponse.

        Array of likes for users who have liked this status.  # noqa: E501

        :param likes: The likes of this StatusUpdateResponse.  # noqa: E501
        :type: list[GoalResponseLikes]
        """

        self._likes = likes

    @property
    def modified_at(self):
        """Gets the modified_at of this StatusUpdateResponse.  # noqa: E501

        The time at which this project status was last modified. *Note: This does not currently reflect any changes in associations such as comments that may have been added or removed from the status.*  # noqa: E501

        :return: The modified_at of this StatusUpdateResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this StatusUpdateResponse.

        The time at which this project status was last modified. *Note: This does not currently reflect any changes in associations such as comments that may have been added or removed from the status.*  # noqa: E501

        :param modified_at: The modified_at of this StatusUpdateResponse.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def num_hearts(self):
        """Gets the num_hearts of this StatusUpdateResponse.  # noqa: E501

        *Deprecated - please use likes instead* The number of users who have hearted this status.  # noqa: E501

        :return: The num_hearts of this StatusUpdateResponse.  # noqa: E501
        :rtype: int
        """
        return self._num_hearts

    @num_hearts.setter
    def num_hearts(self, num_hearts):
        """Sets the num_hearts of this StatusUpdateResponse.

        *Deprecated - please use likes instead* The number of users who have hearted this status.  # noqa: E501

        :param num_hearts: The num_hearts of this StatusUpdateResponse.  # noqa: E501
        :type: int
        """

        self._num_hearts = num_hearts

    @property
    def num_likes(self):
        """Gets the num_likes of this StatusUpdateResponse.  # noqa: E501

        The number of users who have liked this status.  # noqa: E501

        :return: The num_likes of this StatusUpdateResponse.  # noqa: E501
        :rtype: int
        """
        return self._num_likes

    @num_likes.setter
    def num_likes(self, num_likes):
        """Sets the num_likes of this StatusUpdateResponse.

        The number of users who have liked this status.  # noqa: E501

        :param num_likes: The num_likes of this StatusUpdateResponse.  # noqa: E501
        :type: int
        """

        self._num_likes = num_likes

    @property
    def parent(self):
        """Gets the parent of this StatusUpdateResponse.  # noqa: E501


        :return: The parent of this StatusUpdateResponse.  # noqa: E501
        :rtype: StatusUpdateResponseParent
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this StatusUpdateResponse.


        :param parent: The parent of this StatusUpdateResponse.  # noqa: E501
        :type: StatusUpdateResponseParent
        """

        self._parent = parent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatusUpdateResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatusUpdateResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StatusUpdateBase(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'title': 'str',
        'resource_subtype': 'str',
        'text': 'str',
        'html_text': 'str',
        'status_type': 'str'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'title': 'title',
        'resource_subtype': 'resource_subtype',
        'text': 'text',
        'html_text': 'html_text',
        'status_type': 'status_type'
    }

    def __init__(self, gid=None, resource_type=None, title=None, resource_subtype=None, text=None, html_text=None, status_type=None):  # noqa: E501
        """StatusUpdateBase - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._title = None
        self._resource_subtype = None
        self._text = None
        self._html_text = None
        self._status_type = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if title is not None:
            self.title = title
        if resource_subtype is not None:
            self.resource_subtype = resource_subtype
        self.text = text
        if html_text is not None:
            self.html_text = html_text
        self.status_type = status_type

    @property
    def gid(self):
        """Gets the gid of this StatusUpdateBase.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this StatusUpdateBase.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this StatusUpdateBase.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this StatusUpdateBase.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this StatusUpdateBase.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this StatusUpdateBase.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this StatusUpdateBase.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this StatusUpdateBase.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def title(self):
        """Gets the title of this StatusUpdateBase.  # noqa: E501

        The title of the status update.  # noqa: E501

        :return: The title of this StatusUpdateBase.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this StatusUpdateBase.

        The title of the status update.  # noqa: E501

        :param title: The title of this StatusUpdateBase.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def resource_subtype(self):
        """Gets the resource_subtype of this StatusUpdateBase.  # noqa: E501

        The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning. The `resource_subtype`s for `status` objects represent the type of their parent.  # noqa: E501

        :return: The resource_subtype of this StatusUpdateBase.  # noqa: E501
        :rtype: str
        """
        return self._resource_subtype

    @resource_subtype.setter
    def resource_subtype(self, resource_subtype):
        """Sets the resource_subtype of this StatusUpdateBase.

        The subtype of this resource. Different subtypes retain many of the same fields and behavior, but may render differently in Asana or represent resources with different semantic meaning. The `resource_subtype`s for `status` objects represent the type of their parent.  # noqa: E501

        :param resource_subtype: The resource_subtype of this StatusUpdateBase.  # noqa: E501
        :type: str
        """
        allowed_values = ["project_status_update", "portfolio_status_update", "goal_status_update"]  # noqa: E501
        if resource_subtype not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_subtype` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_subtype, allowed_values)
            )

        self._resource_subtype = resource_subtype

    @property
    def text(self):
        """Gets the text of this StatusUpdateBase.  # noqa: E501

        The text content of the status update.  # noqa: E501

        :return: The text of this StatusUpdateBase.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this StatusUpdateBase.

        The text content of the status update.  # noqa: E501

        :param text: The text of this StatusUpdateBase.  # noqa: E501
        :type: str
        """
        if text is None:
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def html_text(self):
        """Gets the html_text of this StatusUpdateBase.  # noqa: E501

        [Opt In](/docs/inputoutput-options). The text content of the status update with formatting as HTML.  # noqa: E501

        :return: The html_text of this StatusUpdateBase.  # noqa: E501
        :rtype: str
        """
        return self._html_text

    @html_text.setter
    def html_text(self, html_text):
        """Sets the html_text of this StatusUpdateBase.

        [Opt In](/docs/inputoutput-options). The text content of the status update with formatting as HTML.  # noqa: E501

        :param html_text: The html_text of this StatusUpdateBase.  # noqa: E501
        :type: str
        """

        self._html_text = html_text

    @property
    def status_type(self):
        """Gets the status_type of this StatusUpdateBase.  # noqa: E501

        The type associated with the status update. This represents the current state of the object this object is on.  # noqa: E501

        :return: The status_type of this StatusUpdateBase.  # noqa: E501
        :rtype: str
        """
        return self._status_type

    @status_type.setter
    def status_type(self, status_type):
        """Sets the status_type of this StatusUpdateBase.

        The type associated with the status update. This represents the current state of the object this object is on.  # noqa: E501

        :param status_type: The status_type of this StatusUpdateBase.  # noqa: E501
        :type: str
        """
        if status_type is None:
            raise ValueError("Invalid value for `status_type`, must not be `None`")  # noqa: E501
        allowed_values = ["on_track", "at_risk", "off_track", "on_hold", "complete", "achieved", "partial", "missed", "dropped"]  # noqa: E501
        if status_type not in allowed_values:
            raise ValueError(
                "Invalid value for `status_type` ({0}), must be one of {1}"  # noqa: E501
                .format(status_type, allowed_values)
            )

        self._status_type = status_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatusUpdateBase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatusUpdateBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UserBaseResponsePhoto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'image_21x21': 'str',
        'image_27x27': 'str',
        'image_36x36': 'str',
        'image_60x60': 'str',
        'image_128x128': 'str',
        'image_1024x1024': 'str'
    }

    attribute_map = {
        'image_21x21': 'image_21x21',
        'image_27x27': 'image_27x27',
        'image_36x36': 'image_36x36',
        'image_60x60': 'image_60x60',
        'image_128x128': 'image_128x128',
        'image_1024x1024': 'image_1024x1024'
    }

    def __init__(self, image_21x21=None, image_27x27=None, image_36x36=None, image_60x60=None, image_128x128=None, image_1024x1024=None):  # noqa: E501
        """UserBaseResponsePhoto - a model defined in Swagger"""  # noqa: E501
        self._image_21x21 = None
        self._image_27x27 = None
        self._image_36x36 = None
        self._image_60x60 = None
        self._image_128x128 = None
        self._image_1024x1024 = None
        self.discriminator = None
        if image_21x21 is not None:
            self.image_21x21 = image_21x21
        if image_27x27 is not None:
            self.image_27x27 = image_27x27
        if image_36x36 is not None:
            self.image_36x36 = image_36x36
        if image_60x60 is not None:
            self.image_60x60 = image_60x60
        if image_128x128 is not None:
            self.image_128x128 = image_128x128
        if image_1024x1024 is not None:
            self.image_1024x1024 = image_1024x1024

    @property
    def image_21x21(self):
        """Gets the image_21x21 of this UserBaseResponsePhoto.  # noqa: E501


        :return: The image_21x21 of this UserBaseResponsePhoto.  # noqa: E501
        :rtype: str
        """
        return self._image_21x21

    @image_21x21.setter
    def image_21x21(self, image_21x21):
        """Sets the image_21x21 of this UserBaseResponsePhoto.


        :param image_21x21: The image_21x21 of this UserBaseResponsePhoto.  # noqa: E501
        :type: str
        """

        self._image_21x21 = image_21x21

    @property
    def image_27x27(self):
        """Gets the image_27x27 of this UserBaseResponsePhoto.  # noqa: E501


        :return: The image_27x27 of this UserBaseResponsePhoto.  # noqa: E501
        :rtype: str
        """
        return self._image_27x27

    @image_27x27.setter
    def image_27x27(self, image_27x27):
        """Sets the image_27x27 of this UserBaseResponsePhoto.


        :param image_27x27: The image_27x27 of this UserBaseResponsePhoto.  # noqa: E501
        :type: str
        """

        self._image_27x27 = image_27x27

    @property
    def image_36x36(self):
        """Gets the image_36x36 of this UserBaseResponsePhoto.  # noqa: E501


        :return: The image_36x36 of this UserBaseResponsePhoto.  # noqa: E501
        :rtype: str
        """
        return self._image_36x36

    @image_36x36.setter
    def image_36x36(self, image_36x36):
        """Sets the image_36x36 of this UserBaseResponsePhoto.


        :param image_36x36: The image_36x36 of this UserBaseResponsePhoto.  # noqa: E501
        :type: str
        """

        self._image_36x36 = image_36x36

    @property
    def image_60x60(self):
        """Gets the image_60x60 of this UserBaseResponsePhoto.  # noqa: E501


        :return: The image_60x60 of this UserBaseResponsePhoto.  # noqa: E501
        :rtype: str
        """
        return self._image_60x60

    @image_60x60.setter
    def image_60x60(self, image_60x60):
        """Sets the image_60x60 of this UserBaseResponsePhoto.


        :param image_60x60: The image_60x60 of this UserBaseResponsePhoto.  # noqa: E501
        :type: str
        """

        self._image_60x60 = image_60x60

    @property
    def image_128x128(self):
        """Gets the image_128x128 of this UserBaseResponsePhoto.  # noqa: E501


        :return: The image_128x128 of this UserBaseResponsePhoto.  # noqa: E501
        :rtype: str
        """
        return self._image_128x128

    @image_128x128.setter
    def image_128x128(self, image_128x128):
        """Sets the image_128x128 of this UserBaseResponsePhoto.


        :param image_128x128: The image_128x128 of this UserBaseResponsePhoto.  # noqa: E501
        :type: str
        """

        self._image_128x128 = image_128x128

    @property
    def image_1024x1024(self):
        """Gets the image_1024x1024 of this UserBaseResponsePhoto.  # noqa: E501


        :return: The image_1024x1024 of this UserBaseResponsePhoto.  # noqa: E501
        :rtype: str
        """
        return self._image_1024x1024

    @image_1024x1024.setter
    def image_1024x1024(self, image_1024x1024):
        """Sets the image_1024x1024 of this UserBaseResponsePhoto.


        :param image_1024x1024: The image_1024x1024 of this UserBaseResponsePhoto.  # noqa: E501
        :type: str
        """

        self._image_1024x1024 = image_1024x1024

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserBaseResponsePhoto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserBaseResponsePhoto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from asana.api_client import ApiClient


class StatusUpdatesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_status_for_object(self, body, **kwargs):  # noqa: E501
        """Create a status update  # noqa: E501

        Creates a new status update on an object. Returns the full record of the newly created status update.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_status_for_object(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StatusUpdatesBody body: The status update to create. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StatusUpdateResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_status_for_object_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_status_for_object_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_status_for_object_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create a status update  # noqa: E501

        Creates a new status update on an object. Returns the full record of the newly created status update.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_status_for_object_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param StatusUpdatesBody body: The status update to create. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StatusUpdateResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'limit', 'offset', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_status_for_object" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_status_for_object`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/status_updates', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusUpdateResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_status(self, status_update_gid, **kwargs):  # noqa: E501
        """Delete a status update  # noqa: E501

        Deletes a specific, existing status update.  Returns an empty data record.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_status(status_update_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_update_gid: The status update to get. (required)
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_status_with_http_info(status_update_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_status_with_http_info(status_update_gid, **kwargs)  # noqa: E501
            return data

    def delete_status_with_http_info(self, status_update_gid, **kwargs):  # noqa: E501
        """Delete a status update  # noqa: E501

        Deletes a specific, existing status update.  Returns an empty data record.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_status_with_http_info(status_update_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_update_gid: The status update to get. (required)
        :return: EmptyResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['status_update_gid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'status_update_gid' is set
        if ('status_update_gid' not in params or
                params['status_update_gid'] is None):
            raise ValueError("Missing the required parameter `status_update_gid` when calling `delete_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_update_gid' in params:
            path_params['status_update_gid'] = params['status_update_gid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/status_updates/{status_update_gid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_status(self, status_update_gid, **kwargs):  # noqa: E501
        """Get a status update  # noqa: E501

        Returns the complete record for a single status update.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_status(status_update_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_update_gid: The status update to get. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StatusUpdateResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_status_with_http_info(status_update_gid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_status_with_http_info(status_update_gid, **kwargs)  # noqa: E501
            return data

    def get_status_with_http_info(self, status_update_gid, **kwargs):  # noqa: E501
        """Get a status update  # noqa: E501

        Returns the complete record for a single status update.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_status_with_http_info(status_update_gid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str status_update_gid: The status update to get. (required)
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StatusUpdateResponseData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['status_update_gid', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'status_update_gid' is set
        if ('status_update_gid' not in params or
                params['status_update_gid'] is None):
            raise ValueError("Missing the required parameter `status_update_gid` when calling `get_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'status_update_gid' in params:
            path_params['status_update_gid'] = params['status_update_gid']  # noqa: E501

        query_params = []
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/status_updates/{status_update_gid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusUpdateResponseData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_statuses_for_object(self, parent, **kwargs):  # noqa: E501
        """Get status updates from an object  # noqa: E501

        Returns the compact status update records for all updates on the object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_statuses_for_object(parent, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str parent: Globally unique identifier for object to fetch statuses from. Must be a GID for a project, portfolio, or goal. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param datetime created_since: Only return statuses that have been created since the given time.
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StatusUpdateResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_statuses_for_object_with_http_info(parent, **kwargs)  # noqa: E501
        else:
            (data) = self.get_statuses_for_object_with_http_info(parent, **kwargs)  # noqa: E501
            return data

    def get_statuses_for_object_with_http_info(self, parent, **kwargs):  # noqa: E501
        """Get status updates from an object  # noqa: E501

        Returns the compact status update records for all updates on the object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_statuses_for_object_with_http_info(parent, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str parent: Globally unique identifier for object to fetch statuses from. Must be a GID for a project, portfolio, or goal. (required)
        :param int limit: Results per page. The number of objects to return per page. The value must be between 1 and 100.
        :param str offset: Offset token. An offset to the next page returned by the API. A pagination request will return an offset token, which can be used as an input parameter to the next request. If an offset is not passed in, the API will return the first page of results. 'Note: You can only pass in an offset that was returned to you via a previously paginated request.'
        :param datetime created_since: Only return statuses that have been created since the given time.
        :param list[str] opt_fields: This endpoint returns a compact resource, which excludes some properties by default. To include those optional properties, set this query parameter to a comma-separated list of the properties you wish to include.
        :return: StatusUpdateResponseArray
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['parent', 'limit', 'offset', 'created_since', 'opt_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_statuses_for_object" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'parent' is set
        if ('parent' not in params or
                params['parent'] is None):
            raise ValueError("Missing the required parameter `parent` when calling `get_statuses_for_object`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'parent' in params:
            query_params.append(('parent', params['parent']))  # noqa: E501
        if 'created_since' in params:
            query_params.append(('created_since', params['created_since']))  # noqa: E501
        if 'opt_fields' in params:
            query_params.append(('opt_fields', params['opt_fields']))  # noqa: E501
            collection_formats['opt_fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json; charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/status_updates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StatusUpdateResponseArray',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProjectDuplicateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'team': 'str',
        'include': 'str',
        'schedule_dates': 'ProjectDuplicateRequestScheduleDates'
    }

    attribute_map = {
        'name': 'name',
        'team': 'team',
        'include': 'include',
        'schedule_dates': 'schedule_dates'
    }

    def __init__(self, name=None, team=None, include=None, schedule_dates=None):  # noqa: E501
        """ProjectDuplicateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._team = None
        self._include = None
        self._schedule_dates = None
        self.discriminator = None
        self.name = name
        if team is not None:
            self.team = team
        if include is not None:
            self.include = include
        if schedule_dates is not None:
            self.schedule_dates = schedule_dates

    @property
    def name(self):
        """Gets the name of this ProjectDuplicateRequest.  # noqa: E501

        The name of the new project.  # noqa: E501

        :return: The name of this ProjectDuplicateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProjectDuplicateRequest.

        The name of the new project.  # noqa: E501

        :param name: The name of this ProjectDuplicateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def team(self):
        """Gets the team of this ProjectDuplicateRequest.  # noqa: E501

        Sets the team of the new project. If team is not defined, the new project will be in the same team as the the original project.  # noqa: E501

        :return: The team of this ProjectDuplicateRequest.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this ProjectDuplicateRequest.

        Sets the team of the new project. If team is not defined, the new project will be in the same team as the the original project.  # noqa: E501

        :param team: The team of this ProjectDuplicateRequest.  # noqa: E501
        :type: str
        """

        self._team = team

    @property
    def include(self):
        """Gets the include of this ProjectDuplicateRequest.  # noqa: E501

        A comma-separated list of elements that will be duplicated to the new project. Tasks are always included. ##### Fields - forms - members - notes - task_assignee - task_attachments - task_dates - task_dependencies - task_followers - task_notes - task_projects - task_subtasks - task_tags  # noqa: E501

        :return: The include of this ProjectDuplicateRequest.  # noqa: E501
        :rtype: str
        """
        return self._include

    @include.setter
    def include(self, include):
        """Sets the include of this ProjectDuplicateRequest.

        A comma-separated list of elements that will be duplicated to the new project. Tasks are always included. ##### Fields - forms - members - notes - task_assignee - task_attachments - task_dates - task_dependencies - task_followers - task_notes - task_projects - task_subtasks - task_tags  # noqa: E501

        :param include: The include of this ProjectDuplicateRequest.  # noqa: E501
        :type: str
        """

        self._include = include

    @property
    def schedule_dates(self):
        """Gets the schedule_dates of this ProjectDuplicateRequest.  # noqa: E501


        :return: The schedule_dates of this ProjectDuplicateRequest.  # noqa: E501
        :rtype: ProjectDuplicateRequestScheduleDates
        """
        return self._schedule_dates

    @schedule_dates.setter
    def schedule_dates(self, schedule_dates):
        """Sets the schedule_dates of this ProjectDuplicateRequest.


        :param schedule_dates: The schedule_dates of this ProjectDuplicateRequest.  # noqa: E501
        :type: ProjectDuplicateRequestScheduleDates
        """

        self._schedule_dates = schedule_dates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectDuplicateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectDuplicateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AuditLogEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'created_at': 'datetime',
        'event_type': 'str',
        'event_category': 'str',
        'actor': 'AuditLogEventActor',
        'resource': 'AuditLogEventResource',
        'details': 'object',
        'context': 'AuditLogEventContext'
    }

    attribute_map = {
        'gid': 'gid',
        'created_at': 'created_at',
        'event_type': 'event_type',
        'event_category': 'event_category',
        'actor': 'actor',
        'resource': 'resource',
        'details': 'details',
        'context': 'context'
    }

    def __init__(self, gid=None, created_at=None, event_type=None, event_category=None, actor=None, resource=None, details=None, context=None):  # noqa: E501
        """AuditLogEvent - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._created_at = None
        self._event_type = None
        self._event_category = None
        self._actor = None
        self._resource = None
        self._details = None
        self._context = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if created_at is not None:
            self.created_at = created_at
        if event_type is not None:
            self.event_type = event_type
        if event_category is not None:
            self.event_category = event_category
        if actor is not None:
            self.actor = actor
        if resource is not None:
            self.resource = resource
        if details is not None:
            self.details = details
        if context is not None:
            self.context = context

    @property
    def gid(self):
        """Gets the gid of this AuditLogEvent.  # noqa: E501

        Globally unique identifier of the `AuditLogEvent`, as a string.  # noqa: E501

        :return: The gid of this AuditLogEvent.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this AuditLogEvent.

        Globally unique identifier of the `AuditLogEvent`, as a string.  # noqa: E501

        :param gid: The gid of this AuditLogEvent.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def created_at(self):
        """Gets the created_at of this AuditLogEvent.  # noqa: E501

        The time the event was created.  # noqa: E501

        :return: The created_at of this AuditLogEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AuditLogEvent.

        The time the event was created.  # noqa: E501

        :param created_at: The created_at of this AuditLogEvent.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def event_type(self):
        """Gets the event_type of this AuditLogEvent.  # noqa: E501

        The type of the event.  # noqa: E501

        :return: The event_type of this AuditLogEvent.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this AuditLogEvent.

        The type of the event.  # noqa: E501

        :param event_type: The event_type of this AuditLogEvent.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def event_category(self):
        """Gets the event_category of this AuditLogEvent.  # noqa: E501

        The category that this `event_type` belongs to.  # noqa: E501

        :return: The event_category of this AuditLogEvent.  # noqa: E501
        :rtype: str
        """
        return self._event_category

    @event_category.setter
    def event_category(self, event_category):
        """Sets the event_category of this AuditLogEvent.

        The category that this `event_type` belongs to.  # noqa: E501

        :param event_category: The event_category of this AuditLogEvent.  # noqa: E501
        :type: str
        """

        self._event_category = event_category

    @property
    def actor(self):
        """Gets the actor of this AuditLogEvent.  # noqa: E501


        :return: The actor of this AuditLogEvent.  # noqa: E501
        :rtype: AuditLogEventActor
        """
        return self._actor

    @actor.setter
    def actor(self, actor):
        """Sets the actor of this AuditLogEvent.


        :param actor: The actor of this AuditLogEvent.  # noqa: E501
        :type: AuditLogEventActor
        """

        self._actor = actor

    @property
    def resource(self):
        """Gets the resource of this AuditLogEvent.  # noqa: E501


        :return: The resource of this AuditLogEvent.  # noqa: E501
        :rtype: AuditLogEventResource
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this AuditLogEvent.


        :param resource: The resource of this AuditLogEvent.  # noqa: E501
        :type: AuditLogEventResource
        """

        self._resource = resource

    @property
    def details(self):
        """Gets the details of this AuditLogEvent.  # noqa: E501

        Event specific details. The schema will vary depending on the `event_type`.  # noqa: E501

        :return: The details of this AuditLogEvent.  # noqa: E501
        :rtype: object
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this AuditLogEvent.

        Event specific details. The schema will vary depending on the `event_type`.  # noqa: E501

        :param details: The details of this AuditLogEvent.  # noqa: E501
        :type: object
        """

        self._details = details

    @property
    def context(self):
        """Gets the context of this AuditLogEvent.  # noqa: E501


        :return: The context of this AuditLogEvent.  # noqa: E501
        :rtype: AuditLogEventContext
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this AuditLogEvent.


        :param context: The context of this AuditLogEvent.  # noqa: E501
        :type: AuditLogEventContext
        """

        self._context = context

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AuditLogEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PortfolioResponseCustomFieldSettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'project': 'CustomFieldSettingResponseProject',
        'is_important': 'bool',
        'parent': 'CustomFieldSettingResponseParent',
        'custom_field': 'CustomFieldSettingResponseCustomField'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'project': 'project',
        'is_important': 'is_important',
        'parent': 'parent',
        'custom_field': 'custom_field'
    }

    def __init__(self, gid=None, resource_type=None, project=None, is_important=None, parent=None, custom_field=None):  # noqa: E501
        """PortfolioResponseCustomFieldSettings - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._project = None
        self._is_important = None
        self._parent = None
        self._custom_field = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if project is not None:
            self.project = project
        if is_important is not None:
            self.is_important = is_important
        if parent is not None:
            self.parent = parent
        if custom_field is not None:
            self.custom_field = custom_field

    @property
    def gid(self):
        """Gets the gid of this PortfolioResponseCustomFieldSettings.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this PortfolioResponseCustomFieldSettings.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this PortfolioResponseCustomFieldSettings.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this PortfolioResponseCustomFieldSettings.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def project(self):
        """Gets the project of this PortfolioResponseCustomFieldSettings.  # noqa: E501


        :return: The project of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :rtype: CustomFieldSettingResponseProject
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this PortfolioResponseCustomFieldSettings.


        :param project: The project of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :type: CustomFieldSettingResponseProject
        """

        self._project = project

    @property
    def is_important(self):
        """Gets the is_important of this PortfolioResponseCustomFieldSettings.  # noqa: E501

        `is_important` is used in the Asana web application to determine if this custom field is displayed in the list/grid view of a project or portfolio.  # noqa: E501

        :return: The is_important of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :rtype: bool
        """
        return self._is_important

    @is_important.setter
    def is_important(self, is_important):
        """Sets the is_important of this PortfolioResponseCustomFieldSettings.

        `is_important` is used in the Asana web application to determine if this custom field is displayed in the list/grid view of a project or portfolio.  # noqa: E501

        :param is_important: The is_important of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :type: bool
        """

        self._is_important = is_important

    @property
    def parent(self):
        """Gets the parent of this PortfolioResponseCustomFieldSettings.  # noqa: E501


        :return: The parent of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :rtype: CustomFieldSettingResponseParent
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this PortfolioResponseCustomFieldSettings.


        :param parent: The parent of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :type: CustomFieldSettingResponseParent
        """

        self._parent = parent

    @property
    def custom_field(self):
        """Gets the custom_field of this PortfolioResponseCustomFieldSettings.  # noqa: E501


        :return: The custom_field of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :rtype: CustomFieldSettingResponseCustomField
        """
        return self._custom_field

    @custom_field.setter
    def custom_field(self, custom_field):
        """Sets the custom_field of this PortfolioResponseCustomFieldSettings.


        :param custom_field: The custom_field of this PortfolioResponseCustomFieldSettings.  # noqa: E501
        :type: CustomFieldSettingResponseCustomField
        """

        self._custom_field = custom_field

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PortfolioResponseCustomFieldSettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PortfolioResponseCustomFieldSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GoalRequestBase(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gid': 'str',
        'resource_type': 'str',
        'name': 'str',
        'html_notes': 'str',
        'notes': 'str',
        'due_on': 'str',
        'start_on': 'str',
        'is_workspace_level': 'bool',
        'liked': 'bool',
        'team': 'str',
        'workspace': 'str',
        'time_period': 'str',
        'owner': 'str'
    }

    attribute_map = {
        'gid': 'gid',
        'resource_type': 'resource_type',
        'name': 'name',
        'html_notes': 'html_notes',
        'notes': 'notes',
        'due_on': 'due_on',
        'start_on': 'start_on',
        'is_workspace_level': 'is_workspace_level',
        'liked': 'liked',
        'team': 'team',
        'workspace': 'workspace',
        'time_period': 'time_period',
        'owner': 'owner'
    }

    def __init__(self, gid=None, resource_type=None, name=None, html_notes=None, notes=None, due_on=None, start_on=None, is_workspace_level=None, liked=None, team=None, workspace=None, time_period=None, owner=None):  # noqa: E501
        """GoalRequestBase - a model defined in Swagger"""  # noqa: E501
        self._gid = None
        self._resource_type = None
        self._name = None
        self._html_notes = None
        self._notes = None
        self._due_on = None
        self._start_on = None
        self._is_workspace_level = None
        self._liked = None
        self._team = None
        self._workspace = None
        self._time_period = None
        self._owner = None
        self.discriminator = None
        if gid is not None:
            self.gid = gid
        if resource_type is not None:
            self.resource_type = resource_type
        if name is not None:
            self.name = name
        if html_notes is not None:
            self.html_notes = html_notes
        if notes is not None:
            self.notes = notes
        if due_on is not None:
            self.due_on = due_on
        if start_on is not None:
            self.start_on = start_on
        if is_workspace_level is not None:
            self.is_workspace_level = is_workspace_level
        if liked is not None:
            self.liked = liked
        if team is not None:
            self.team = team
        if workspace is not None:
            self.workspace = workspace
        if time_period is not None:
            self.time_period = time_period
        if owner is not None:
            self.owner = owner

    @property
    def gid(self):
        """Gets the gid of this GoalRequestBase.  # noqa: E501

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :return: The gid of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._gid

    @gid.setter
    def gid(self, gid):
        """Sets the gid of this GoalRequestBase.

        Globally unique identifier of the resource, as a string.  # noqa: E501

        :param gid: The gid of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._gid = gid

    @property
    def resource_type(self):
        """Gets the resource_type of this GoalRequestBase.  # noqa: E501

        The base type of this resource.  # noqa: E501

        :return: The resource_type of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this GoalRequestBase.

        The base type of this resource.  # noqa: E501

        :param resource_type: The resource_type of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def name(self):
        """Gets the name of this GoalRequestBase.  # noqa: E501

        The name of the goal.  # noqa: E501

        :return: The name of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GoalRequestBase.

        The name of the goal.  # noqa: E501

        :param name: The name of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def html_notes(self):
        """Gets the html_notes of this GoalRequestBase.  # noqa: E501

        The notes of the goal with formatting as HTML.  # noqa: E501

        :return: The html_notes of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._html_notes

    @html_notes.setter
    def html_notes(self, html_notes):
        """Sets the html_notes of this GoalRequestBase.

        The notes of the goal with formatting as HTML.  # noqa: E501

        :param html_notes: The html_notes of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._html_notes = html_notes

    @property
    def notes(self):
        """Gets the notes of this GoalRequestBase.  # noqa: E501

        Free-form textual information associated with the goal (i.e. its description).  # noqa: E501

        :return: The notes of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this GoalRequestBase.

        Free-form textual information associated with the goal (i.e. its description).  # noqa: E501

        :param notes: The notes of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def due_on(self):
        """Gets the due_on of this GoalRequestBase.  # noqa: E501

        The localized day on which this goal is due. This takes a date with format `YYYY-MM-DD`.  # noqa: E501

        :return: The due_on of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._due_on

    @due_on.setter
    def due_on(self, due_on):
        """Sets the due_on of this GoalRequestBase.

        The localized day on which this goal is due. This takes a date with format `YYYY-MM-DD`.  # noqa: E501

        :param due_on: The due_on of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._due_on = due_on

    @property
    def start_on(self):
        """Gets the start_on of this GoalRequestBase.  # noqa: E501

        The day on which work for this goal begins, or null if the goal has no start date. This takes a date with `YYYY-MM-DD` format, and cannot be set unless there is an accompanying due date.  # noqa: E501

        :return: The start_on of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._start_on

    @start_on.setter
    def start_on(self, start_on):
        """Sets the start_on of this GoalRequestBase.

        The day on which work for this goal begins, or null if the goal has no start date. This takes a date with `YYYY-MM-DD` format, and cannot be set unless there is an accompanying due date.  # noqa: E501

        :param start_on: The start_on of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._start_on = start_on

    @property
    def is_workspace_level(self):
        """Gets the is_workspace_level of this GoalRequestBase.  # noqa: E501

        *Conditional*. This property is only present when the `workspace` provided is an organization. Whether the goal belongs to the `workspace` (and is listed as part of the workspace’s goals) or not. If it isn’t a workspace-level goal, it is a team-level goal, and is associated with the goal’s team.  # noqa: E501

        :return: The is_workspace_level of this GoalRequestBase.  # noqa: E501
        :rtype: bool
        """
        return self._is_workspace_level

    @is_workspace_level.setter
    def is_workspace_level(self, is_workspace_level):
        """Sets the is_workspace_level of this GoalRequestBase.

        *Conditional*. This property is only present when the `workspace` provided is an organization. Whether the goal belongs to the `workspace` (and is listed as part of the workspace’s goals) or not. If it isn’t a workspace-level goal, it is a team-level goal, and is associated with the goal’s team.  # noqa: E501

        :param is_workspace_level: The is_workspace_level of this GoalRequestBase.  # noqa: E501
        :type: bool
        """

        self._is_workspace_level = is_workspace_level

    @property
    def liked(self):
        """Gets the liked of this GoalRequestBase.  # noqa: E501

        True if the goal is liked by the authorized user, false if not.  # noqa: E501

        :return: The liked of this GoalRequestBase.  # noqa: E501
        :rtype: bool
        """
        return self._liked

    @liked.setter
    def liked(self, liked):
        """Sets the liked of this GoalRequestBase.

        True if the goal is liked by the authorized user, false if not.  # noqa: E501

        :param liked: The liked of this GoalRequestBase.  # noqa: E501
        :type: bool
        """

        self._liked = liked

    @property
    def team(self):
        """Gets the team of this GoalRequestBase.  # noqa: E501

        *Conditional*. This property is only present when the `workspace` provided is an organization.  # noqa: E501

        :return: The team of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this GoalRequestBase.

        *Conditional*. This property is only present when the `workspace` provided is an organization.  # noqa: E501

        :param team: The team of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._team = team

    @property
    def workspace(self):
        """Gets the workspace of this GoalRequestBase.  # noqa: E501

        The `gid` of a workspace.  # noqa: E501

        :return: The workspace of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this GoalRequestBase.

        The `gid` of a workspace.  # noqa: E501

        :param workspace: The workspace of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._workspace = workspace

    @property
    def time_period(self):
        """Gets the time_period of this GoalRequestBase.  # noqa: E501

        The `gid` of a time period.  # noqa: E501

        :return: The time_period of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._time_period

    @time_period.setter
    def time_period(self, time_period):
        """Sets the time_period of this GoalRequestBase.

        The `gid` of a time period.  # noqa: E501

        :param time_period: The time_period of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._time_period = time_period

    @property
    def owner(self):
        """Gets the owner of this GoalRequestBase.  # noqa: E501

        The `gid` of a user.  # noqa: E501

        :return: The owner of this GoalRequestBase.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this GoalRequestBase.

        The `gid` of a user.  # noqa: E501

        :param owner: The owner of this GoalRequestBase.  # noqa: E501
        :type: str
        """

        self._owner = owner

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GoalRequestBase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GoalRequestBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
